<?php

if(!defined('DOKU_INC')) die();
if(!defined('DOKU_PLUGIN')) define('DOKU_PLUGIN',DOKU_INC.'lib/plugins/');
require_once(DOKU_PLUGIN.'action.php');


class action_plugin_fckg_cache extends DokuWiki_Action_Plugin {

  var $pos = false;
  /**
   * return some info
   */
  function getInfo(){
    return array(
                 'author' => 'Myron Turner',
                 'email'  => 'turnermm03@shaw.ca',
                 'date'   => '2007-09-18',
                 'name'   => 'Cach Use',
                 'desc'   => 'Prevents Caching',
                 'url'    => 'http://www.mturner.org',
                 );
  }


  /*
   * Register its handlers with the dokuwiki's event controller
   */
  function register(&$controller) {
          $user_agent = $_SERVER['HTTP_USER_AGENT'];
          if(preg_match('/Firefox/i', $user_agent)) return;
          $controller->register_hook('PARSER_CACHE_USE', 'BEFORE', $this, 'fckg_cache_bypass');
          
  }


    function fckg_cache_bypass(&$event, $param)
    {
      if(!$this->pos && file_exists($event->data->file)) {     
         $data=file_get_contents($event->data->file);
         $this->pos = strpos($data,"<indent");
     }
     if($this->pos === false) {
           return;
     }

            $event->preventDefault();
            $event->stopPropagation();
            $event->result = false;
    }



}




